@@ -1,13 +1,10 @@
-import sys
-import os
-import requests
-import urllib3
-import urllib3
 import json
-from dsmigrator.logging import log
+
+import requests
+
 from dsmigrator.api_config import ComputerGroupsApiInstance
-from dsmigrator.migrator_utils import validate_create_dict, rename_json
-from deepsecurity.rest import ApiException
+from dsmigrator.logging import log
+from dsmigrator.migrator_utils import rename_json, validate_create_dict
 
 cert = False
 
