@@ -1,22 +1,14 @@
-import sys
-import os
-import time
-from time import sleep
-import requests
-import urllib3
-import urllib3
 import json
-from dsmigrator.logging import log
+
+import requests
+
 from dsmigrator.api_config import (
     DirectoryListsApiInstance,
-    FileListsApiInstance,
     FileExtensionListsApiInstance,
+    FileListsApiInstance,
 )
-from dsmigrator.migrator_utils import (
-    validate_create,
-    rename_json,
-    safe_request,
-)
+from dsmigrator.logging import log
+from dsmigrator.migrator_utils import safe_request, validate_create
 
 cert = False
 
@@ -844,7 +836,7 @@ def ScheduleGet(url_link_final, tenant1key):
 
 
 def ScheduleCreate(t1scheduleall, t1schedulename, url_link_final_2, tenant2key):
-    schedule_id_dict = {}
+    schedule_id_dict = {0: 0}
     t2scheduleid = []
     log.info("Transfering All Schedule Configuration...")
     if t1schedulename:
